@@ -19,11 +19,11 @@ Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 module Dpkg where
 -- Interface to Dpkg/Apt
 
-import MissingH.Cmd
-import MissingH.Debian.ControlParser
-import MissingH.Maybe
-import MissingH.Logging.Logger
-import MissingH.Str
+import System.Cmd.Utils
+import System.Debian.ControlParser
+import Data.Maybe.Utils
+import System.Log.Logger
+import Data.String
 import Text.Regex
 import Utils
 
@@ -64,7 +64,7 @@ getBuildDeps package =
 
 pkgVerToFilename :: String -> String -> String
 pkgVerToFilename package version =
-    let newvers = subRe (mkRegex "^[0-9]+:") version ""
+    let newvers = subRegex (mkRegex "^[0-9]+:") version ""
         in
         package ++ "_" ++ newvers ++ "_*.deb"
 
@@ -81,4 +81,4 @@ getDebDeps package version =
                                         Nothing -> []
                                         Just z -> splitted z
                             in
-                            return $ find "Depends"
\ No newline at end of file
+                            return $ find "Depends"
